==> novell-xattr-devel-2006.06.20-1linux.tar.gz: novell-xattr-devel-2006.06.20-1linux/public/chunk.h <==
/****************************************************************************
 |
 |	(C) Copyright 2001 Novell, Inc.
 |	All Rights Reserved.
 |
 |	This program is free software; you can redistribute it and/or
 |	modify it under the terms of version 2 of the GNU General Public
 |	License as published by the Free Software Foundation.
 |
 |	This program is distributed in the hope that it will be useful,
 |	but WITHOUT ANY WARRANTY; without even the implied warranty of
 |	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 |	GNU General Public License for more details.
 |
 |	You should have received a copy of the GNU General Public License
 |	along with this program; if not, contact Novell, Inc.
 |
 |	To contact Novell about this file by physical or electronic mail,
 |	you may find current contact information at www.novell.com
 |
 |***************************************************************************
 |
 |	 NetWare Storage Services (NSS) module
 |
 |---------------------------------------------------------------------------
 |
 | $Author: taysom $
 | $Date: 2004/12/30 19:40:58 $
 |
 | $RCSfile: chunk.h,v $
 | $Revision: 1.2 $
 |
 |---------------------------------------------------------------------------
 |	This module is used to:
 |		Define a chunk which is used to do pass cache buffers around.
 +-------------------------------------------------------------------------*/
#ifndef _CHUNK_H_
#define _CHUNK_H_

#ifndef _ZOMNI_H_
#	include <zOmni.h>
#endif

typedef struct Chunk_s
{
	BYTE	*start;
	NINT	length;
	ADDR	handle;
	voidfunc_t	release;
} Chunk_s;

#endif

==> novell-xattr-devel-2007.10.03-1linux.tar.gz: novell-xattr-devel-2007.10.03-1linux/public/chunk.h <==
/****************************************************************************
 |
 |	(C) Copyright 2001 Novell, Inc.
 |	All Rights Reserved.
 |
 |	This program is free software; you can redistribute it and/or
 |	modify it under the terms of version 2 of the GNU General Public
 |	License as published by the Free Software Foundation.
 |
 |	This program is distributed in the hope that it will be useful,
 |	but WITHOUT ANY WARRANTY; without even the implied warranty of
 |	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 |	GNU General Public License for more details.
 |
 |	You should have received a copy of the GNU General Public License
 |	along with this program; if not, contact Novell, Inc.
 |
 |	To contact Novell about this file by physical or electronic mail,
 |	you may find current contact information at www.novell.com
 |
 |***************************************************************************
 |
 |	 NetWare Storage Services (NSS) module
 |
 |---------------------------------------------------------------------------
 |
 | $Author: vandana $
 | $Date: 2006-10-30 15:29:05 -0600 (Mon, 30 Oct 2006) $
 |
 | $RCSfile$
 | $Revision: 1585 $
 |
 |---------------------------------------------------------------------------
 |	This module is used to:
 |		Define a chunk which is used to do pass cache buffers around.
 +-------------------------------------------------------------------------*/
#ifndef _CHUNK_H_
#define _CHUNK_H_

#ifndef _ZOMNI_H_
#	include <zOmni.h>
#endif

typedef struct NSSChunk_s
{
	NINT	nc_offset;
	NINT	nc_length;
	ADDR	nc_handle;
	voidfunc_t	nc_release;
} NSSChunk_s;

#endif
